@@ -33,7 +33,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGES.
  *
- * $Id: ah_osdep.h 4061 2009-06-26 01:31:05Z proski $
+ * $Id: ah_osdep.h 4107 2010-01-13 06:50:17Z proski $
  */
 #ifndef _ATH_AH_OSDEP_H_
 #define _ATH_AH_OSDEP_H_
@@ -64,6 +64,7 @@ struct ath_hal_chip *AR5212_chip_ptr __attribute__((__weak__));	\
 struct ath_hal_chip *AR5312_chip_ptr __attribute__((__weak__));	\
 struct ath_hal_chip *AR5416_chip_ptr __attribute__((__weak__));	\
 struct ath_hal_chip *AR9160_chip_ptr __attribute__((__weak__));	\
+struct ath_hal_chip *AR9280_chip_ptr __attribute__((__weak__));	\
 struct ath_hal_chip *const *ah_chips_ptrs[] = {			\
 	&AR5210_chip_ptr,					\
 	&AR5211_chip_ptr,					\
@@ -71,6 +72,7 @@ struct ath_hal_chip *const *ah_chips_ptrs[] = {			\
 	&AR5312_chip_ptr,					\
 	&AR5416_chip_ptr,					\
 	&AR9160_chip_ptr,					\
+	&AR9280_chip_ptr,					\
 	NULL							\
 }
 
