@@ -33,7 +33,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGES.
  *
- * $Id: sample.c 4095 2009-09-03 21:08:13Z proski $
+ * $Id: sample.c 4097 2009-09-19 04:03:53Z proski $
  */
 
 
@@ -254,7 +254,7 @@ calc_usecs_unicast_packet(struct ath_softc *sc, int length,
 	tt += (long_retries+1)*ath_hal_computetxtime(sc->sc_ah, rt, length,
 						rix, AH_TRUE);
 	for (x = 0; x <= short_retries + long_retries; x++) {
-		cw = MIN(ATH_DEFAULT_CWMAX, (cw + 1) * 2);
+		cw = MIN(ATH_DEFAULT_CWMAX, (cw << 1) | 1);
 		tt += (t_slot * cw / 2);
 	}
 	return tt;
